A dataframe-like object but using a simple list of (non-record) arrays
as the core data structure.

Supports sorting, indexing, grouping, etc.

Work in progress, but already heavy on features and solid on testing.
